@@ -1,7 +1,5 @@
 package org.gcube.portal.istischeduler.impl;
 
-import java.io.File;
-import java.io.FileInputStream;
 import java.sql.Connection;
 import java.sql.DriverManager;
 import java.sql.PreparedStatement;
@@ -12,8 +10,6 @@ import java.sql.Timestamp;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
-import java.util.Properties;
-import java.util.ResourceBundle;
 
 import org.gcube.portal.istischeduler.SiManager;
 import org.gcube.portal.istischeduler.model.SiEntry;
@@ -21,8 +17,6 @@ import org.gcube.portal.istischeduler.model.SiServerEntry;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.liferay.portal.kernel.dao.db.DB;
-import com.liferay.portal.kernel.dao.db.DBFactoryUtil;
 import com.liferay.portal.kernel.dao.jdbc.DataAccess;
 /**
  * Create 2 auxiliary tables needed by Si (Sistema informativo ISTI) to update the Liferay DB correctly
@@ -34,7 +28,9 @@ public class LiferaySiManager implements SiManager {
 	 * logger
 	 */
 	private static final Logger _log = LoggerFactory.getLogger(LiferaySiManager.class);
-
+	
+	private static final String IDSOCIALISTI = "socialisti";
+	
 	private static final String ISTI_SI_FLOWS_TABLE = "_isti_flows";
 	private static final String ISTI_SI_LOGS_TABLE = "_isti_logs";
 
@@ -82,6 +78,8 @@ public class LiferaySiManager implements SiManager {
 	 */
 	@Override
 	public boolean updateSiEntry(SiEntry entry) throws SQLException {
+		if (con == null || con.isClosed())
+			con = getDBConnection();
 		_log.trace("Updating Si Entry in Table Flows where id = " + entry.getId());
 		String insert = "UPDATE "+ISTI_SI_FLOWS_TABLE+" SET tab = ?, operation = ?, flowid = ?, lastupdate = ? WHERE id = ?";
 
@@ -101,7 +99,8 @@ public class LiferaySiManager implements SiManager {
 	 */
 	@Override
 	public SiEntry getSiEntryById(long id) throws SQLException {
-
+		if (con == null || con.isClosed())
+			con = getDBConnection();
 		String select = "SELECT * FROM "+ISTI_SI_FLOWS_TABLE+" where id = ?";
 		PreparedStatement statement = con.prepareStatement(select);
 		statement.setLong(1, id);
@@ -118,6 +117,8 @@ public class LiferaySiManager implements SiManager {
 	 */
 	@Override
 	public List<SiEntry> listSiEntries() throws SQLException {
+		if (con == null || con.isClosed())
+			con = getDBConnection();
 		String select = "SELECT * FROM "+ISTI_SI_FLOWS_TABLE;
 		PreparedStatement statement = con.prepareStatement(select);
 		ResultSet rs = statement.executeQuery();
@@ -136,6 +137,8 @@ public class LiferaySiManager implements SiManager {
 	 */
 	@Override
 	public boolean addSiLogEntry(Date logDate, String logResult, String logInfo) throws SQLException {
+		if (con == null || con.isClosed())
+			con = getDBConnection();
 		_log.trace("Adding Si Entry in Table Logs");
 		String insert = "INSERT into " + ISTI_SI_LOGS_TABLE + "(timestamp, result, info) values(?, ?, ?)";
 
@@ -156,35 +159,6 @@ public class LiferaySiManager implements SiManager {
 	 * @throws SQLException
 	 */
 	private Connection getDBConnection() throws SQLException {
-//		Properties props = new Properties();
-//		String propertyfile = getTomcatFolder()+"webapps/ROOT/WEB-INF/classes/portal-ext.properties";			
-//		File propsFile = new File(propertyfile);
-//		FileInputStream fis;
-//
-//		String dbUrl = "";
-//		String dbUser = "";
-//		String dbPassword = "";
-//
-//		try {
-//			fis = new FileInputStream(propsFile);
-//			props.load( fis);
-//			dbUrl = props.getProperty("jdbc.default.url");
-//			dbUser = props.getProperty("jdbc.default.username");
-//			dbPassword = props.getProperty("jdbc.default.password");
-//
-//		} catch (Exception e) {
-//			_log.error("Problems reading LR portal-ext.properties file, using fallback configuration see org.gcube.portal.istischeduler#settings.properties");
-//
-//			ResourceBundle rb = ResourceBundle.getBundle("org.gcube.portal.istischeduler.settings");
-//			dbUrl = rb.getString("PG_PROVIDER_URL");
-//			dbUser = rb.getString("PG_SECURITY_PRINCIPAL");
-//			dbPassword = rb.getString("PG_SECURITY_CREDENTIALS");
-//		} 
-//
-//		_log.info("Liferay DB Settings Found, using db at: " + dbUrl);
-//		_log.info("passwd=" + dbPassword);
-//
-//		return DriverManager.getConnection(dbUrl, dbUser, dbPassword);	
 		_log.info("Trying to get Connection From API");
 		Connection toReturn = DataAccess.getConnection();
 		_log.info("CONNECTED TO LR DB!");
@@ -250,13 +224,19 @@ public class LiferaySiManager implements SiManager {
 
 			statement.setInt(1, 2);
 			statement.setString(2, "mail");
+			statement.setString(3, "R");
+			statement.setLong(4, 0L);
+			statement.setTimestamp(5, null);
 			statement.executeUpdate();
 
 			statement.setInt(1, 3);
 			statement.setString(2, "posizioni");
+			statement.setString(3, "R");
+			statement.setLong(4, 0L);
+			statement.setTimestamp(5, null);
 			statement.executeUpdate();
 
-			_log.info("Table Flows Popoluted, returning ...");
+			_log.info("Table Flows Populated, returning ...");
 
 		} catch (SQLException e) {
 			e.printStackTrace();
@@ -271,6 +251,77 @@ public class LiferaySiManager implements SiManager {
 		}
 		return true;
 	}
+	/**
+	 * 
+	 * @param tables the tables affected by the operation
+	 * @throws SQLException
+	 */
+	public static void log2SIStart(String tables) throws SQLException {
+		
+		String dbUrl = "jdbc:postgresql://" + LiferaySiManager.getSiTestEndPoint().getHostName()+":"+LiferaySiManager.getSiTestEndPoint().getPort()+"/"+LiferaySiManager.getSiTestEndPoint().getDbName();
+		String dbUser = LiferaySiManager.getSiTestEndPoint().getUser();
+		String dbPassword = LiferaySiManager.getSiTestEndPoint().getPassword();
+		Connection connectionSI = null;
+		try {
+			connectionSI =  DriverManager.getConnection(dbUrl, dbUser, dbPassword);
+			Statement stm = connectionSI.createStatement();
+			stm.execute("INSERT INTO master_log (codice_flusso, tabelle, operazione, data_inizio_oper) "
+					+ "VALUES ('"
+					+ IDSOCIALISTI
+					+ "','"+tables+"','L',current_timestamp)");
+
+		} catch (SQLException e) {
+			_log.error("Error during master_log write"	+ e.getMessage());
+			connectionSI.close();
+		} finally {
+			try {
+				connectionSI.close();
+			} catch (SQLException ex) {
+				_log.error("Error during master_log db closure"	+ ex.getMessage());
+			}
+		}
+	}
+	/**
+	 * 
+	 * @param tables the tables affected by the operation
+	 * @throws SQLException
+	 */
+	public static void log2SIFinish(String tables) throws SQLException {
+		String dbUrl = "jdbc:postgresql://" + LiferaySiManager.getSiTestEndPoint().getHostName()+":"+LiferaySiManager.getSiTestEndPoint().getPort()+"/"+LiferaySiManager.getSiTestEndPoint().getDbName();
+		String dbUser = LiferaySiManager.getSiTestEndPoint().getUser();
+		String dbPassword = LiferaySiManager.getSiTestEndPoint().getPassword();
+		Connection connectionSI = null;
+		try {
+			long id_flusso = 0;
+			connectionSI =  DriverManager.getConnection(dbUrl, dbUser, dbPassword);
+			
+			Statement stm = connectionSI.createStatement();
+			ResultSet rs = stm.executeQuery("SELECT  id_flusso FROM master_log WHERE codice_flusso='"
+					+ IDSOCIALISTI
+					+ "' AND operazione='L' AND data_fine_oper IS NULL ORDER BY id_flusso DESC");
+		
+			if (rs.next()) {
+				id_flusso = rs.getLong("id_flusso");
+				stm.executeUpdate("UPDATE master_log SET data_fine_oper=current_timestamp, tabelle='"
+						+ tables
+						+ "', esito_oper='OK' WHERE codice_flusso='"
+						+ IDSOCIALISTI + "' AND id_flusso=" + id_flusso + " ");
+			} else {
+				_log.error("Could not get idflusso");
+			}			
+		} catch (SQLException e) {
+			_log.error("Error during master_log update"	+ e.getMessage());
+			connectionSI.close();
+		} finally {
+			try {
+				connectionSI.close();
+			} catch (SQLException ex) {
+				_log.error("Error during master_log db closure"	+ ex.getMessage());
+			}
+		}
+	}
+	
+	
 
 	/**
 	 * 
@@ -290,4 +341,9 @@ public class LiferaySiManager implements SiManager {
 	public SiServerEntry getSiEndPoint() {
 		return new SiServerEntry("sistemainformativo", "SI DB Endpoint", "sistemainformativo-dev.isti.cnr.it", "5432", "socialisti", "!socialisti_123");
 	}
+	
+	
+	public static SiServerEntry getSiTestEndPoint() {
+		return new SiServerEntry("sistemainformativo", "SI DB Endpoint", "sistemainformativo-dev.isti.cnr.it", "5432", "socialisti", "!socialisti_123");
+	}
 }
